@@ -4,11 +4,12 @@
 import unittest
 import copy
 import locale
+import ctypes
 
 from decimal import Decimal
 from locale_utils import get_avail_locales, requires_locales
 
-from bytesize import Size
+from bytesize import Size, ROUND_UP, ROUND_DOWN, KiB
 
 class SizeTestCase(unittest.TestCase):
 
@@ -252,6 +253,10 @@ class SizeTestCase(unittest.TestCase):
         self.assertFalse(size2)
     #enddef
 
+    def testInt(self):
+        # just to make sure Size can be correctly interpreted as int in python 3.10
+        ctypes.c_int(Size("1 GiB"))
+
     def testAbs(self):
         size1 = Size("1 GiB")
         self.assertEqual(size1, abs(size1))
@@ -300,6 +305,17 @@ class SizeTestCase(unittest.TestCase):
 
         locale.setlocale(locale.LC_ALL,'en_US.UTF-8')
 
+    def testRoundToNearest(self):
+        size = Size("1.5 KiB")
+        conv = size.round_to_nearest(Size("1 KiB"), rounding=ROUND_UP)
+        self.assertEqual(conv, Size("2 KiB"))
+
+        conv = size.round_to_nearest(KiB, rounding=ROUND_DOWN)
+        self.assertEqual(conv, Size("1 KiB"))
+
+        with self.assertRaises(ValueError):
+            size.round_to_nearest(-1, rounding=ROUND_UP)
+
 #endclass
 
 # script entry point
