@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 import locale
@@ -6,9 +6,16 @@ import unittest
 import sys
 import ctypes
 
-from locale_utils import get_avail_locales, requires_locales
+from locale_utils import get_avail_locales, missing_locales, requires_locales
 
-from bytesize import SizeStruct, KiB, GiB, ROUND_UP, ROUND_DOWN, ROUND_HALF_UP, OverflowError
+from bytesize import KiB, GiB, ROUND_UP, ROUND_DOWN, ROUND_HALF_UP, OverflowError
+
+# SizeStruct is part of the 'private' API and needs to be imported differently
+# when running from locally build tree and when using installed library
+try:
+    from bytesize import SizeStruct
+except ImportError:
+    from bytesize.bytesize import SizeStruct
 
 DEFAULT_LOCALE = "en_US.utf8"
 
@@ -19,8 +26,10 @@ class SizeTestCase(unittest.TestCase):
         unittest.TestCase.setUpClass()
         cls.avail_locales = get_avail_locales()
 
-    @requires_locales({DEFAULT_LOCALE})
     def setUp(self):
+        missing = missing_locales({DEFAULT_LOCALE}, self.avail_locales)
+        if missing:
+            self.skipTest("requires missing locales: %s" % missing)
         locale.setlocale(locale.LC_ALL, DEFAULT_LOCALE)
         self.addCleanup(self._clean_up)
 
@@ -759,4 +768,3 @@ if __name__=='__main__':
         sys.argv = [sys.argv[0]]
     unittest.main()
 #endif
-
