@@ -25,28 +25,20 @@ if [ $# -ne 1 ]; then
 fi
 
 status=0
-while read project_name branch ; do
-    echo "Testing $project_name:$branch"
+while read -r project_name l10n_git ; do
+    echo "Testing $project_name"
 
-    podir="$(mktemp -d ${project_name}-${branch}.XXXXXX)"
+    podir="$(mktemp -d "${project_name}".XXXXXX)"
 
-    # The zanata output only matters if something goes wrong
-    zanata_output="$(zanata pull --project-type gettext --project-id "$project_name" --project-version "$branch" --transdir "$podir" --url https://fedora.zanata.org/ 2>&1)"
-    if [ $? -ne 0 ]; then
-        echo "Zanata pull failed for $project_name:$branch"
-        echo "$zanata_output"
-        status=1
-        rm -rf "$podir"
-        continue
-    fi
+    # Download translations
+    git clone --depth 1 -- "$l10n_git" "$podir"
 
     # Ignore the percent-translated warnings
-    python3 -W ignore -m translation_canary.translated "$podir"
-    if [ $? -ne 0 ]; then
-        echo "Canary test failed for $project_name:$branch"
+    if ! python3 -W ignore -m translation_canary.translated "$podir"; then
+        echo "Canary test failed for $project_name"
         status=1
     else
-        echo "Success: $project_name:$branch"
+        echo "Success: $project_name"
     fi
 
     rm -rf "$podir"
